@@ -51,7 +51,7 @@ __all__ = [
     "libejdb_version"
 ]
 
-version_tuple = (1, 0, 11)
+version_tuple = (1, 0, 15)
 
 def get_version_string():
     return '.'.join(map(str, version_tuple))
@@ -185,6 +185,52 @@ class EJDB(object):
     def sync(self):
         return self.__ejdb.sync()
 
+    def command(self, cmd):
+        """ Executes ejdb database command.
+
+          Supported commands:
+
+           1) Exports database collections data. See ejdbexport() method.
+
+             "export" : {
+                   "path" : string,                    //Exports database collections data
+                   "cnames" : [string array]|null,     //List of collection names to export
+                   "mode" : int|null                   //Values: null|`JBJSONEXPORT` See ejdb.h#ejdbexport() method
+             }
+
+             Command response:
+                {
+                   "log" : string,        //Diagnostic log about executing this command
+                   "error" : string|null, //ejdb error message
+                   "errorCode" : int|0,   //ejdb error code
+                }
+
+           2) Imports previously exported collections data into ejdb.
+
+             "import" : {
+                   "path" : string                     //The directory path in which data resides
+                   "cnames" : [string array]|null,     //List of collection names to import
+                   "mode" : int|null                //Values: null| JBIMPORTUPDATE`|`JBIMPORTREPLACE` See ejdb.h#ejdbimport() method
+              }
+
+              Command response:
+                {
+                   "log" : string,        //Diagnostic log about executing this command
+                   "error" : string|null, //ejdb error message
+                   "errorCode" : int|0,   //ejdb error code
+                }
+
+         :Parameters:
+            - `cmd`  Command object dictionary
+
+         :Returns:
+            Command response object dictionary
+        """
+        bret = self.__ejdb.command(bson.serialize_to_bytes(cmd))
+        if bret is not None:
+            return bson.parse_bytes(bret)
+        return None
+
     def save(self, cname, *jsarr, **kwargs):
         """ Save/update specified `dict` documents into collection `cname`.
 
